@@ -1,17 +1,30 @@
-"""map.py
+"""
+MIT License
 
-Class
------
-SimpleMapLocation
-    A simple location
-MapLocation
-    Map location
-Map
-    A Map control
+Copyright (c) 2020 DashIO-Connect
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
 """
 import datetime
 import json
 
+from ..constants import BAD_CHARS
 from .control import Control
 from .enums import TitlePosition
 
@@ -20,7 +33,7 @@ class SimpleMapLocation:
     """
     A non json map location.
     """
-    def __init__(self, tag: str, latitude: str, longitude: str):
+    def __init__(self, track_id: str, latitude: str, longitude: str):
         """A map location used by a map_control
 
         Parameters
@@ -28,27 +41,25 @@ class SimpleMapLocation:
                 Latitude
             longitude : str
                 Longitude
-            tag : str
-                A tag to display on the map.
+            track_id : str
+                A track_id for the track.
         """
-        self.latitude = latitude
-        self.longitude = longitude
-        self.tag = tag
+        self.latitude = latitude.translate(BAD_CHARS)
+        self.longitude = longitude.translate(BAD_CHARS)
+        self.track_id = track_id.translate(BAD_CHARS)
 
     def __str__(self):
-        return f"{self.latitude}\t{self.longitude}\t{self.tag}\n"
+        return f"{self.track_id}\t{self.latitude},{self.longitude}\n"
 
 class MapLocation:
     """
     A json version of a map location.
     """
-    def __init__(self, tag: str, latitude: str, longitude: str, average_speed=None, peak_speed=None, course=None, altitude=None, distance=None):
+    def __init__(self, latitude: str, longitude: str, average_speed=None, peak_speed=None, course=None, altitude=None, distance=None, message=None):
         """MapLocation
 
         Parameters
         ----------
-        tag : str
-            Location tag
         latitude : str
             The latitude
         longitude : str
@@ -63,13 +74,14 @@ class MapLocation:
             altitude, by default None
         distance : str, optional
             distance, by default None
+        message : str, optional
+            Displayed with the pin on the map of the DashIO Dashboard
         """
         self.timestamp = datetime.datetime.utcnow().replace(microsecond=0, tzinfo=datetime.timezone.utc)
         self._map_loc = {}
         self._map_loc["time"] = self.timestamp.isoformat()
-        self._map_loc["message"] = tag
-        self._map_loc["latitude"] = latitude
-        self._map_loc["longitude"] = longitude
+        self._map_loc["latitude"] = latitude.translate(BAD_CHARS)
+        self._map_loc["longitude"] = longitude.translate(BAD_CHARS)
         if average_speed:
             self._map_loc["avgeSpeed"] = average_speed
         if peak_speed:
@@ -80,6 +92,8 @@ class MapLocation:
             self._map_loc["altitude"] = altitude
         if distance:
             self._map_loc["distance"] = distance
+        if message:
+            self._map_loc["message"] = message
 
     def __str__(self):
         return json.dumps(self._map_loc) + "\n"
